# Test suite for utils functions

context("apis_in_catalogue.R")

test_that(desc="test connections to apis in catalogue",{  
  
  skip_on_cran()
  
#  apis <- names(api_parameters())
  
#  for(api in apis){
#    expect_true(suppressMessages(pxweb_api$new(api)$test_api()))
#  }
})
